summaryrefslogtreecommitdiff
path: root/src/terminal.c
diff options
context:
space:
mode:
authorMartin Rudalics <rudalics@gmx.at>2008-12-22 09:40:33 +0000
committerMartin Rudalics <rudalics@gmx.at>2008-12-22 09:40:33 +0000
commit56f2de103fd8ee430ae3d2f6a1b83d4aa2012f90 (patch)
tree4dcbba9b999a65c7919278eb93fd5b821f9b5b2d /src/terminal.c
parentcaf857eb7c7815e1d11ed706fb4a789bc92c3924 (diff)
downloademacs-56f2de103fd8ee430ae3d2f6a1b83d4aa2012f90.tar.gz
* frame.c (delete_frame): New function derived from
Fdelete_frame to handle Qnoelisp value for FORCE argument. Delete last frame iff FORCE equals Qnoelisp. (Bug#1450) (Fdelete_frame): Call delete_frame. Remove line from doc-string saying that FORCE non-nil doesn't run `delete-frame-functions'. * frame.h: Extern delete_frame. * window.c (window_loop): * terminal.c (delete_terminal): * xterm.c (x_connection_closed): * xfns.c (Fx_hide_tip): * w32fns.c (Fx_hide_tip): Call delete_frame instead of Fdelete_frame.
Diffstat (limited to 'src/terminal.c')
-rw-r--r--src/terminal.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/terminal.c b/src/terminal.c
index 6b6edf14316..0b1e9f32576 100644
--- a/src/terminal.c
+++ b/src/terminal.c
@@ -256,7 +256,7 @@ delete_terminal (struct terminal *terminal)
struct terminal **tp;
Lisp_Object tail, frame;
/* Protect against recursive calls. Fdelete_frame calls the
delete_terminal_hook when we delete our last frame. */
if (!terminal->name)
return;
@@ -269,8 +269,8 @@ delete_terminal (struct terminal *terminal)
struct frame *f = XFRAME (frame);
if (FRAME_LIVE_P (f) && f->terminal == terminal)
{
- /* Maybe this should pass Qnoelisp rather than Qt? */
- Fdelete_frame (frame, Qt);
+ /* Pass Qnoelisp rather than Qt. */
+ delete_frame (frame, Qnoelisp);
}
}
@@ -283,7 +283,7 @@ delete_terminal (struct terminal *terminal)
terminal->keyboard_coding = NULL;
xfree (terminal->terminal_coding);
terminal->terminal_coding = NULL;
-
+
if (terminal->kboard && --terminal->kboard->reference_count == 0)
{
delete_kboard (terminal->kboard);
@@ -315,7 +315,7 @@ but if the second argument FORCE is non-nil, you may do so. */)
struct terminal *p = terminal_list;
while (p && (p == t || !TERMINAL_ACTIVE_P (p)))
p = p->next_terminal;
-
+
if (!p)
error ("Attempt to delete the sole active display terminal");
}
@@ -376,7 +376,7 @@ possible return values. */)
Lisp_Object object;
{
struct terminal *t;
-
+
t = get_terminal (object, 0);
if (!t)
@@ -256,7 +256,7 @@ delete_terminal (struct terminal *terminal)
struct terminal **tp;
Lisp_Object tail, frame;
- /* Protect against recursive calls. Fdelete_frame calls the
+ /* Protect against recursive calls. delete_frame calls the
delete_terminal_hook when we delete our last frame. */
if (!terminal->name)